.. class:: center

  .. image:: https://imgur.com/pY1WUFX.png
    :target: https://github.com/Cog-Creators/Red-DiscordBot/tree/V3/develop
    :alt: Red Discord Bot
  
  
.. class:: center
  
  Music, Moderation, Trivia, Stream Alerts and fully customizable.

.. class:: center

  .. image:: https://readthedocs.org/projects/red-discordbot/badge/?version=v3-develop
    :target: http://red-discordbot.readthedocs.io/en/v3-develop/?badge=v3-develop
    :alt: Documentation Status

  .. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black
    :alt: Code style: black

  .. image:: https://d322cqt584bo4o.cloudfront.net/red-discordbot/localized.svg
    :target: https://crowdin.com/project/red-discordbot
    :alt: Crowdin

  .. image:: https://img.shields.io/badge/Support-Red!-orange.svg
    :target: https://www.patreon.com/Red_Devs
    :alt: Patreon

==========
Overview
==========

Red is a fully modular bot – meaning all features and commands can be enabled/disabled to your liking, making it completely customizable.  
This is also a *self-hosted bot* – meaning you will need to host and maintain your own instance. You can turn Red into an admin bot, music bot, trivia bot, new best friend or all of these together!  

`Installation <#installation>`_ is easy, and you do **NOT** need to know anything about coding! Aside from installation and updating, every part of the bot can be controlled from within Discord.

**The default set of modules includes and is not limited to:**

- Moderation features (kick/ban/softban/hackban, mod-log, filter, chat cleanup)
- Trivia (lists are included and can be easily added)
- Music features (YouTube, SoundCloud, local files, playlists, queues)
- Stream alerts (Twitch, Youtube, Mixer, Hitbox, Picarto)
- Slot machine
- Custom commands
- Imgur/gif search


**Additionally, other plugins (cogs) can be easily found and added from our growing community of cog repositories.**

- Cleverbot integration (talk to Red and she talks back)
- Ban sync
- Welcome messages
- Casino
- Reaction roles
- Slow Mode
- Anilist
- And much, much more!

Feel free to take a `peek <https://github.com/Cog-Creators/Red-DiscordBot/issues/1398>`_!

==============
Installation
==============

**The following platforms are officially supported:** 

- `Windows <https://red-discordbot.readthedocs.io/en/v3-develop/install_windows.html>`_
- `MacOS <https://red-discordbot.readthedocs.io/en/v3-develop/install_mac.html>`_
- `Ubuntu <https://red-discordbot.readthedocs.io/en/v3-develop/install_ubuntu.html>`_
- `Debian Stretch <https://red-discordbot.readthedocs.io/en/v3-develop/install_debian.html>`_
- `CentOS 7 <https://red-discordbot.readthedocs.io/en/v3-develop/install_centos.html>`_
- `Arch Linux <https://red-discordbot.readthedocs.io/en/v3-develop/install_arch.html>`_
- `Raspbian Stretch <https://red-discordbot.readthedocs.io/en/v3-develop/install_raspbian.html>`_

Already using **Red** V2? Take a look at the `Data Converter <https://red-discordbot.readthedocs.io/en/v3-develop/cog_dataconverter.html>`_ to import your data to V3.

If `after reading the guides <https://red-discordbot.readthedocs.io/en/v3-develop/>`_ you are still experiencing issues, feel free to join the `Official Server <https://discord.gg/red>`_ and ask in the **#support** channel for help. 

=====================
Join the community!
=====================

**Red** is in continuous development, and it’s supported by an active community which produces new content (cogs/plugins) for everyone to enjoy. New features are constantly added. If you can’t `find <https://github.com/Cog-Creators/Red-DiscordBot/issues/1398>`_ what you’re looking for, consult our `guide <https://red-discordbot.readthedocs.io/en/v3-develop/guide_cog_creation.html>`_ on building your own cogs! 

Join us on our `Official Discord Server <https://discord.gg/red>`_!

=========
License
=========

Released under the `GNU GPL v3 <#License>`_.

Red is named after the main character of "Transistor", a videogame by `Super Giant Games <https://www.supergiantgames.com/games/transistor/>`_

Artwork created by `Sinlaire <https://sinlaire.deviantart.com/>`_ on Deviant Art for the Red Bot Project.
